module.exports = defineTest({
	description:
		'always keep leading comments when tree-shaking and no automatic semicolons are inserted'
});
